"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.decode = void 0;

var _utils = require("blurhash/dist/utils");

var _base = require("blurhash/dist/base83");

// the following code is copied/extracted from https://github.com/woltapp/blurhash/blob/master/TypeScript/src/decode.ts
// license: MIT
// Author: Olli Mahlamäki https://github.com/omahlama
const decodeDC = value => {
  const intR = value >> 16;
  const intG = value >> 8 & 255;
  const intB = value & 255;
  return [(0, _utils.sRGBToLinear)(intR), (0, _utils.sRGBToLinear)(intG), (0, _utils.sRGBToLinear)(intB)];
};

const decodeAC = (value, maximumValue) => {
  const quantR = Math.floor(value / (19 * 19));
  const quantG = Math.floor(value / 19) % 19;
  const quantB = value % 19;
  const rgb = [(0, _utils.signPow)((quantR - 9) / 9, 2.0) * maximumValue, (0, _utils.signPow)((quantG - 9) / 9, 2.0) * maximumValue, (0, _utils.signPow)((quantB - 9) / 9, 2.0) * maximumValue];
  return rgb;
};

const decode = (blurhash, punch = 1) => {
  const sizeFlag = (0, _base.decode83)(blurhash[0]);
  const numY = Math.floor(sizeFlag / 9) + 1;
  const numX = sizeFlag % 9 + 1;
  const quantisedMaximumValue = (0, _base.decode83)(blurhash[1]);
  const maximumValue = (quantisedMaximumValue + 1) / 166;
  const numColors = numX * numY;
  const colors = new Array(numX * numY);

  for (let i = 0; i < numColors; i++) {
    if (i === 0) {
      const value = (0, _base.decode83)(blurhash.substring(2, 6));
      colors[i] = decodeDC(value);
    } else {
      const value = (0, _base.decode83)(blurhash.substring(4 + i * 2, 6 + i * 2));
      colors[i] = decodeAC(value, maximumValue * punch);
    }
  }

  return {
    numX,
    numY,
    colors
  };
};

exports.decode = decode;
//# sourceMappingURL=decode.js.map